@@ -21,11 +21,11 @@ import (
 	"github.com/go-kit/kit/log"
 	"github.com/go-kit/kit/log/level"
 
-	"github.com/open-cluster-management/metrics-collector/pkg/forwarder"
-	telemeterhttp "github.com/open-cluster-management/metrics-collector/pkg/http"
-	"github.com/open-cluster-management/metrics-collector/pkg/logger"
-	"github.com/open-cluster-management/metrics-collector/pkg/metricfamily"
-	"github.com/open-cluster-management/metrics-collector/pkg/utils"
+	"github.com/stolostron/metrics-collector/pkg/forwarder"
+	telemeterhttp "github.com/stolostron/metrics-collector/pkg/http"
+	"github.com/stolostron/metrics-collector/pkg/logger"
+	"github.com/stolostron/metrics-collector/pkg/metricfamily"
+	"github.com/stolostron/metrics-collector/pkg/utils"
 )
 
 func main() {
